@@ -9,6 +9,7 @@ from sa_tools_core.libs.sentry import report
 from sa_tools_core.libs.permission import require_user
 from sa_tools_core.libs.notify.email import send_mail
 from sa_tools_core.libs.notify.wework import send_message as send_wework
+from sa_tools_core.libs.notify.lark import send_message as send_lark
 from sa_tools_core.libs.notify.pushbullet import send_message as send_pushbullet
 from sa_tools_core.libs.notify.pushover import send_message as send_pushover
 from sa_tools_core.libs.notify.telegram import send_message as send_telegram
@@ -19,7 +20,7 @@ from sa_tools_core.consts import SYSADMIN_EMAIL
 logger = logging.getLogger(__name__)
 logging.getLogger("requests").setLevel(logging.WARN)
 
-NOTIFY_TYPES = ("wework", "email", "sms", "pushbullet", "pushover", "telegram")
+NOTIFY_TYPES = ("wework", "lark", "email", "sms", "pushbullet", "pushover", "telegram")
 DEFAULT_TITLE = "Sent from sa-notify"
 DEFAULT_MSG_TYPE = "text"
 
@@ -58,24 +59,33 @@ class Notifier(object):
         raise AttributeError
 
     def _wework(self, addrs, content=None, **kw):
+        content = content if content is not None else self.content
         send_wework(addrs, content, msg_type=self.msg_type)
 
+    def _lark(self, addrs, content=None, **kw):
+        send_lark(addrs, content, **kw)
+
     def _email(self, addrs, content=None, title=None, from_addr=None, **kw):
+        content = content if content is not None else self.content
         send_mail(addrs, content, subject=title, from_addr=from_addr or self.from_addr)
 
     def _pushbullet(self, addrs, content=None, title=None, **kw):
+        content = content if content is not None else self.content
         for addr in addrs:
             send_pushbullet(addr, title, content)
 
     def _pushover(self, addrs, content=None, **kw):
+        content = content if content is not None else self.content
         for addr in addrs:
             send_pushover(addr, content)
 
     def _telegram(self, addrs, content=None, **kw):
+        content = content if content is not None else self.content
         for addr in addrs:
             send_telegram(addr, content, msg_type=self.msg_type)
 
     def _sms(self, addrs, content=None, **kw):
+        content = content if content is not None else self.content
         for addr in addrs:
             send_sms(addr, content)
 
@@ -89,7 +99,7 @@ def notify(args):
         if values:
             addrs = [i for v in values for i in re.split(r"[,\s]+", v)]
             try:
-                getattr(notifier, type_)(addrs, from_addr=args.from_addr)
+                getattr(notifier, type_)(addrs, from_addr=args.from_addr, company=args.company)
             except Exception as e:
                 logger.exception("Notifier.%s(%s) failed: %s", type_, addrs, e)
                 report()
@@ -110,6 +120,7 @@ def main(args=None):
         "-s", "--subject", help='subject. default="%(default)s"', default=DEFAULT_TITLE
     )
     parser.add_argument("-f", "--from-addr", help="From address, currently only works for email.")
+    parser.add_argument("--company", help="Company user in, used when multiple company or tenant is configured.")
     for type_ in NOTIFY_TYPES:
         parser.add_argument(
             "--%s" % type_, nargs="*", help="your enterprise address of %s." % type_
